==> eclipse-platform-ui_4.9.orig.tar.xz: eclipse-platform-ui-4.9/bundles/org.eclipse.ui.workbench/Eclipse UI/org/eclipse/ui/internal/tweaklets/Animations.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2015 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 ******************************************************************************/

package org.eclipse.ui.internal.tweaklets;

import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.internal.RectangleAnimationFeedbackBase;
import org.eclipse.ui.internal.tweaklets.Tweaklets.TweakKey;

/**
 * Animation tweaklet base class. Create (and register) a tweaklet
 * extension derived from this class to provide alternate animation
 * behavior. Currently only affects animations produced by the new
 * min / max behavior.
 *
 * @since 3.3
 *
 */
public abstract class Animations {
	public static TweakKey KEY = new Tweaklets.TweakKey(Animations.class);

	static {
		Tweaklets.setDefault(Animations.KEY, new LegacyAnimations());
	}

	/** Default c'tor */
	public Animations() {}

	/**
	 * Create and return the animation feedback you want to use.
	 *
	 * @param shell The shell that the animation will be in
	 * @return The feedback renderer to use.
	 */
	public abstract RectangleAnimationFeedbackBase createFeedback(Shell shell);
}

==> eclipse-platform-ui_4.12.orig.tar.xz: eclipse-platform-ui-4.12/bundles/org.eclipse.ui.workbench/Eclipse UI/org/eclipse/ui/internal/tweaklets/Animations.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2015 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 ******************************************************************************/

package org.eclipse.ui.internal.tweaklets;

import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.internal.RectangleAnimationFeedbackBase;
import org.eclipse.ui.internal.tweaklets.Tweaklets.TweakKey;

/**
 * Animation tweaklet base class. Create (and register) a tweaklet extension
 * derived from this class to provide alternate animation behavior. Currently
 * only affects animations produced by the new min / max behavior.
 *
 * @since 3.3
 *
 */
public abstract class Animations {
	public static TweakKey KEY = new Tweaklets.TweakKey(Animations.class);

	static {
		Tweaklets.setDefault(Animations.KEY, new LegacyAnimations());
	}

	/** Default c'tor */
	public Animations() {
	}

	/**
	 * Create and return the animation feedback you want to use.
	 *
	 * @param shell The shell that the animation will be in
	 * @return The feedback renderer to use.
	 */
	public abstract RectangleAnimationFeedbackBase createFeedback(Shell shell);
}
